XWinOptions

Struct XWinOptions 

pub struct XWinOptions {
    pub cross_compiler: CrossCompiler,
    pub xwin_cache_dir: Option<PathBuf>,
    pub xwin_arch: Vec<Arch>,
    pub xwin_variant: Vec<Variant>,
    pub xwin_version: u8,
    pub xwin_sdk_version: Option<String>,
    pub xwin_crt_version: Option<String>,
    pub xwin_include_atl: bool,
    pub xwin_include_debug_libs: bool,
    pub xwin_include_debug_symbols: bool,
    pub xwin_http_retries: u32,
}
common xwin options

Fields

cross_compiler: CrossCompiler

The cross compiler to use

xwin_cache_dir: Option<PathBuf>

xwin cache directory

xwin_arch: Vec<Arch>

The architectures to include in CRT/SDK

xwin_variant: Vec<Variant>

The variants to include

xwin_version: u8

The version to retrieve, can either be a major version of 15, 16, 17 or 18, or a “.” version.

xwin_sdk_version: Option<String>

If specified, this is the version of the SDK that the user wishes to use instead of defaulting to the latest SDK available in the the manifest

xwin_crt_version: Option<String>

If specified, this is the version of the MSVCRT that the user wishes to use instead of defaulting to the latest MSVCRT available in the the manifest

xwin_include_atl: bool

Whether to include the Active Template Library (ATL) in the installation

xwin_include_debug_libs: bool

Whether or not to include debug libs

xwin_include_debug_symbols: bool

Whether or not to include debug symbols (PDBs)

xwin_http_retries: u32

Number of times to retry HTTP requests when downloading

Implementations

Source

impl XWinOptions

pub fn apply_command_env( &self, manifest_path: Option<&Path>, cargo: &CommonOptions, cmd: &mut Command, ) -> Result<()>